@@ -12,13 +12,13 @@ BEGIN {
     use vars        qw[ @ISA $VERSION @EXPORT_OK $VERBOSE $ALLOW_UNKNOWN
                         $STRICT_TYPE $STRIP_LEADING_DASHES $NO_DUPLICATES
                         $PRESERVE_CASE $ONLY_ALLOW_DEFINED $WARNINGS_FATAL
-                        $SANITY_CHECK_TEMPLATE $CALLER_DEPTH
+                        $SANITY_CHECK_TEMPLATE
                     ];
 
     @ISA        =   qw[ Exporter ];
     @EXPORT_OK  =   qw[check allow last_error];
 
-    $VERSION                = '0.25';
+    $VERSION                = '0.24';
     $VERBOSE                = $^W ? 1 : 0;
     $NO_DUPLICATES          = 0;
     $STRIP_LEADING_DASHES   = 0;
@@ -28,7 +28,6 @@ BEGIN {
     $ONLY_ALLOW_DEFINED     = 0;
     $SANITY_CHECK_TEMPLATE  = 1;
     $WARNINGS_FATAL         = 0;
-    $CALLER_DEPTH           = 0;
 }
 
 my %known_keys = map { $_ => 1 }
@@ -39,7 +38,7 @@ my %known_keys = map { $_ => 1 }
 
 =head1 NAME
 
-Params::Check - A generic input parsing/checking mechanism.
+Params::Check -- A generic input parsing/checking mechanism.
 
 =head1 SYNOPSIS
 
@@ -507,13 +506,6 @@ sub _sanity_check_and_defaults {
             } grep {
                 not $known_keys{$_}
             } keys %{$utmpl{$key}};
-        
-            ### make sure you passed a ref, otherwise, complain about it!
-            if ( exists $utmpl{$key}->{'store'} ) {
-                _store_error( loc(
-                    q|Store variable for '%1' is not a reference!|, $key
-                ), 1, 1 ) unless ref $utmpl{$key}->{'store'};
-            }
         }
     }
 
@@ -535,7 +527,7 @@ sub _safe_eq {
 sub _who_was_it {
     my $level = $_[0] || 0;
 
-    return (caller(2 + $CALLER_DEPTH + $level))[3] || 'ANON'
+    return (caller(2 + $level))[3] || 'ANON'
 }
 
 =head2 last_error()
@@ -657,30 +649,6 @@ template validation occurs, rather than return C<false>.
 
 Default is 0;
 
-=head2 $Params::Check::CALLER_DEPTH
-
-This global modifies the argument given to C<caller()> by
-C<Params::Check::check()> and is useful if you have a custom wrapper
-function around C<Params::Check::check()>. The value must be an
-integer, indicating the number of wrapper functions inserted between
-the real function call and C<Params::Check::check()>.
-
-Example wrapper function, using a custom stacktrace:
-
-    sub check {
-        my ($template, $args_in) = @_;
-
-        local $Params::Check::WARNINGS_FATAL = 1;
-        local $Params::Check::CALLER_DEPTH = $Params::Check::CALLER_DEPTH + 1;
-        my $args_out = Params::Check::check($template, $args_in);
-
-        my_stacktrace(Params::Check::last_error) unless $args_out;
-
-        return $args_out;
-    }
-
-Default is 0;
-
 =head1 AUTHOR
 
 This module by
