@@ -291,34 +291,46 @@ sub _send_report {
 
     my $grade;
     ### check if this is a platform specific module ###
-    unless( RELEVANT_TEST_RESULT->($mod) ) {
-        msg(loc("'%1' is a platform specific module, and the test results on".
+    ### if we failed the test, there may be reasons why 
+    ### an 'NA' might have to be insted
+    if ( $failed ) {
+        unless( RELEVANT_TEST_RESULT->($mod) ) {
+            msg(loc(
+                "'%1' is a platform specific module, and the test results on".
                 " your platform are not relevant --sending N/A grade.",
                 $name), $verbose);
-
-        $grade = GRADE_NA;
-
-    } elsif ( UNSUPPORTED_OS->( $buffer ) ) {
-        msg(loc("'%1' is a platform specific module, and the test results on".
+        
+            $grade = GRADE_NA;
+        
+        } elsif ( UNSUPPORTED_OS->( $buffer ) ) {
+            msg(loc(
+                "'%1' is a platform specific module, and the test results on".
                 " your platform are not relevant --sending N/A grade.",
                 $name), $verbose);
+        
+            $grade = GRADE_NA;
+        
+        ### you dont have a high enough perl version?    
+        } elsif ( PERL_VERSION_TOO_LOW->( $buffer ) ) {
+            msg(loc("'%1' requires a higher version of perl than your current ".
+                    "version -- sending N/A grade.", $name), $verbose);
+        
+            $grade = GRADE_NA;                
 
-        $grade = GRADE_NA;
+        ### perhaps where were no tests...
+        ### see if the thing even had tests ###
+        } elsif ( NO_TESTS_DEFINED->( $buffer ) ) {
+            $grade = GRADE_UNKNOWN;
 
-    ### you dont have a high enough perl version?    
-    } elsif ( PERL_VERSION_TOO_LOW->( $buffer ) ) {
-        msg(loc("'%1' requires a higher version of perl than your current ".
-                "version -- sending N/A grade.", $name), $verbose);
+        } else {
+            
+            $grade = GRADE_FAIL;
+        }
 
-        $grade = GRADE_NA;                
-
-    ### see if the thing even had tests ###
-    } elsif ( NO_TESTS_DEFINED->( $buffer ) ) {
-        $grade = GRADE_UNKNOWN;
-
-    ### see if it was a pass or fail ###
+    ### if we got here, it didn't fail and tests were present.. so a PASS
+    ### is in order
     } else {
-        $grade = $failed ? GRADE_FAIL : GRADE_PASS;
+        $grade = GRADE_PASS;
     }
 
     ### so an error occurred, let's see what stage it went wrong in ###
@@ -327,7 +339,8 @@ sub _send_report {
 
         ### return if one or more missing external libraries
         if( my @missing = MISSING_EXTLIBS_LIST->($buffer) ) {
-            msg(loc("Not sending test report - external libraries not pre-installed"));
+            msg(loc("Not sending test report - " .
+                    "external libraries not pre-installed"));
             return 1;
         }
 
@@ -350,7 +363,8 @@ sub _send_report {
                                 module  => $mod,
                                 missing => \@missing
                         )) {
-                msg(loc("Not sending test report - bogus missing prerequisites report"));
+                msg(loc("Not sending test report - "  .
+                        "bogus missing prerequisites report"));
                 return 1;
             }
             $message .= REPORT_MISSING_PREREQS->($author,$email,@missing);
