@@ -52,7 +52,7 @@ The flow looks like this:
                 $cb->__retrieve_source
                 $cb->__create_dslip_tree
                     $cb->__retrieve_source
-    $cb->_save_source
+            $cb->_save_source
 
     $cb->_dslip_defs
 
@@ -147,7 +147,7 @@ sub _check_trees {
     return 1 if $conf->get_conf('no_update') && !$update_source;
 
     ### a check to see if our source files are still up to date ###
-    cp_msg( loc("Checking if source files are up to date"), $verbose );
+    msg( loc("Checking if source files are up to date"), $verbose );
 
     my $uptodate = 1; # default return value
 
@@ -231,7 +231,7 @@ sub __check_uptodate {
               return 0;       # return 0 so 'uptodate' will be set to 0, meaning no use
                               # of previously stored hashrefs!
          } else {
-              cp_msg( loc("Unable to update source, attempting to get away with using old source file!"), $args->{verbose} );
+              msg( loc("Unable to update source, attempting to get away with using old source file!"), $args->{verbose} );
               return 1;
          }
 
@@ -293,7 +293,7 @@ sub _update_source {
         ### it's not platform dependant. -kane
         my ($dir, $file) = $conf->_get_mirror( $args->{'name'} ) =~ m|(.+/)(.+)$|sg;
 
-        cp_msg( loc("Updating source file '%1'", $file), $args->{'verbose'} );
+        msg( loc("Updating source file '%1'", $file), $args->{'verbose'} );
 
         my $fake = CPANPLUS::Module::Fake->new(
                         module  => $args->{'name'},
@@ -312,14 +312,14 @@ sub _update_source {
 
 
         unless ($rv) {
-            cp_error( loc("Couldn't fetch '%1'", $file) );
+            error( loc("Couldn't fetch '%1'", $file) );
             return;
         }
 
         ### `touch` the file, so windoze knows it's new -jmb
         ### works on *nix too, good fix -Kane
         utime ( $now, $now, File::Spec->catfile($path, $file) ) or
-            cp_error( loc("Couldn't touch %1", $file) );
+            error( loc("Couldn't touch %1", $file) );
 
     }
     return 1;
@@ -359,7 +359,6 @@ Returns a boolean indicating success.
 =cut
 
 ### (re)build the trees ###
-### takes one optional argument, which indicates if we're already up-to-date. ###
 sub _build_trees {
     my ($self, %hash)   = @_;
     my $conf            = $self->configure_object;
@@ -398,15 +397,18 @@ sub _build_trees {
     ### return if we weren't able to build the trees ###
     return unless $self->{_modtree} && $self->{_authortree};
 
-    ### only do it at the end of the program, not after parsing ###
-    #$self->_save_source( map { $_ => $args->{$_} } qw[path verbose] );
+    ### write the stored files to disk, so we can keep using them
+    ### from now on, till they become invalid
+    ### write them if the original sources weren't uptodate, or
+    ### we didn't just load storable files
+    $self->_save_source() if !$uptodate or not keys %$stored;
 
     ### still necessary? can only run one instance now ###
     ### will probably stay that way --kane
 #     my $id = $self->_store_id( $self );
 #
 #     unless ( $id == $self->_id ) {
-#         cp_error( loc("IDs do not match: %1 != %2. Storage failed!", $id, $self->_id) );
+#         error( loc("IDs do not match: %1 != %2. Storage failed!", $id, $self->_id) );
 #     }
 
     return 1;
@@ -478,7 +480,7 @@ sub __retrieve_source {
                 );
 
     if ($storable && -e $stored && -s _ && $args->{'uptodate'}) {
-        cp_msg( loc("Retrieving %1", $stored), $args->{'verbose'} );
+        msg( loc("Retrieving %1", $stored), $args->{'verbose'} );
 
         my $href = Storable::retrieve($stored);
         return $href;
@@ -555,16 +557,16 @@ sub _save_source {
                         );
 
     if (-e $stored && not -w $stored) {
-        cp_msg( loc("%1 not writable; skipped.", $stored), $args->{'verbose'} );
+        msg( loc("%1 not writable; skipped.", $stored), $args->{'verbose'} );
         return;
     }
 
-    cp_msg( loc("Writing state information back to disk. This may take a little while."),
+    msg( loc("Writing compiled source information to disk. This might take a little while."),
 	    $args->{'verbose'} );
 
     my $flag;
     unless( Storable::nstore( $to_write, $stored ) ) {
-        cp_error( loc("could not store %1!", $stored) );
+        error( loc("could not store %1!", $stored) );
         $flag++;
     }
 
@@ -623,7 +625,7 @@ sub __create_author_tree() {
                                 $conf->_get_source('auth')
                             );
 
-    cp_msg(loc("Rebuilding author tree, this might take a while"),
+    msg(loc("Rebuilding author tree, this might take a while"),
         $args->{verbose});
 
     ### extract the file ###
@@ -706,7 +708,7 @@ sub _create_mod_tree {
     my $args = check( $tmpl, \%hash ) or return undef;
     my $file = File::Spec->catfile($args->{path}, $conf->_get_source('mod'));
 
-    cp_msg(loc("Rebuilding module tree, this might take a while"),
+    msg(loc("Rebuilding module tree, this might take a while"),
         $args->{verbose});
 
 
@@ -757,7 +759,7 @@ sub _create_mod_tree {
 
 
         unless( $self->author_tree($author) ) {
-            cp_error( loc( "No such author '%1' -- can't make module object " .
+            error( loc( "No such author '%1' -- can't make module object " .
                         "'%2' that is supposed to belong to this author",
                         $author, $data[0] ) );
             next;
@@ -896,10 +898,10 @@ sub __create_dslip_tree {
     {   #local $@; can't use this, it's buggy -kane
 
         $cols = eval $ds_one;
-        cp_error( loc("Error in eval of dslip source files: %1", $@) ) if $@;
+        error( loc("Error in eval of dslip source files: %1", $@) ) if $@;
 
         $data = eval $ds_two;
-        cp_error( loc("Error in eval of dslip source files: %1", $@) ) if $@;
+        error( loc("Error in eval of dslip source files: %1", $@) ) if $@;
 
     }
 
