@@ -288,8 +288,8 @@ sub new {
     my $acc = Object::Accessor->new;
     $acc->mk_accessors( qw[ installer_type dist_cpan dist prereqs
                             signature extract fetch readme uninstall
-                            created installed prepared checksums 
-                            checksum_ok checksum_value ] );
+                            created installed prepared checksums files
+                            checksum_ok checksum_value _fetch_from] );
 
     $object->status( $acc );
 
@@ -431,10 +431,18 @@ sub fetch {
     my $self = shift;
     my $cb   = $self->parent;
 
-    my $where = $cb->_fetch( @_, module => $self ) or return;
+    ### custom args
+    my %args            = ( module => $self );
+
+    ### if a custom fetch location got specified before, add that here
+    $args{fetch_from}   = $self->status->_fetch_from 
+                            if $self->status->_fetch_from;
+
+    my $where = $cb->_fetch( @_, %args ) or return;
 
     ### do an md5 check ###
-    if( $cb->configure_object->get_conf('md5') and
+    if( !$self->status->_fetch_from and 
+        $cb->configure_object->get_conf('md5') and
         $self->package ne CHECKSUMS
     ) {
         unless( $self->_validate_checksum ) {
@@ -515,13 +523,13 @@ sub get_installer_type {
     $type = INSTALLER_MM    if  $found_makefile  && !$found_build;
 
     ### ok, so it's a 'build' installer, but you don't /have/ module build
-    if( $type eq INSTALLER_BUILD and 
-        !check_install( module => 'Module::Build' ) 
+    if( $type eq INSTALLER_BUILD and ( 
+            not grep { $_ eq INSTALLER_BUILD } CPANPLUS::Dist->dist_types )
     ) {
-        error( loc( "This module requires '%1' to be installed, ".
+        error( loc( "This module requires '%1' and '%2' to be installed, ".
                     "but you don't have it! Will fall back to ".
-                    "'%2', but might not be able to install!",
-                     'Module::Build', INSTALLER_MM ) );
+                    "'%3', but might not be able to install!",
+                     'Module::Build', INSTALLER_BUILD, INSTALLER_MM ) );
         $type = INSTALLER_MM;
 
     ### ok, actually we found neither ###
@@ -559,6 +567,11 @@ sub dist {
     my $conf = $cb->configure_object;
     my %hash = @_;
 
+    ### have you determined your installer type yet? if not, do it here,
+    ### we need the info
+    $self->get_installer_type unless $self->status->installer_type;
+
+
     my($type,$args,$target);
     my $tmpl = {
         format  => { default => $conf->get_conf('dist_type') ||
@@ -570,10 +583,22 @@ sub dist {
 
     check( $tmpl, \%hash ) or return;
 
-    my $dist = CPANPLUS::Dist->new( format => $type,
-                                    module => $self
+    my $dist = CPANPLUS::Dist->new( 
+                                format => $type,
+                                module => $self
                             ) or return;
 
+    my $dist_cpan = $type eq $self->status->installer_type
+                        ? $dist
+                        : CPANPLUS::Dist->new(
+                                format  => $self->status->installer_type,
+                                module  => $self,
+                            );           
+
+    ### store the dists
+    $self->status->dist_cpan(   $dist_cpan );
+    $self->status->dist(        $dist );
+    
     DIST: {
         ### first prepare the dist
         $dist->prepare( %$args ) or return;
@@ -768,6 +793,19 @@ sub install {
                         "-- Not trusting this module, aborting install",
                         $self->module ) );
             $self->status->signature(0);
+            
+            ### send out test report on broken sig
+            if( $conf->get_conf('cpantest') ) {
+                $cb->_send_report( 
+                    module  => $self,
+                    failed  => 1,
+                    buffer  => CPANPLUS::Error->stack_as_string,
+                    verbose => $args->{verbose},
+                    force   => $args->{force},
+                ) or error(loc("Failed to send test report for '%1'",
+                     $self->module ) );
+            }  
+            
             return;
 
         } else {
@@ -900,6 +938,7 @@ success and returns false on failure.
 
 sub readme {
     my $self = shift;
+    my $conf = $self->parent->configure_object;    
 
     ### did we already dl the readme once? ###
     return $self->status->readme() if $self->status->readme();
@@ -916,7 +955,18 @@ sub readme {
     my $pkg = README->( $obj );
     $obj->package($pkg);
 
-    my $file = $obj->fetch or return;
+    my $file;
+    {   ### disable checksum fetches on readme downloads
+        
+        my $tmp = $conf->get_conf( 'md5' );
+        $conf->set_conf( md5 => 0 );
+        
+        $file = $obj->fetch;
+
+        $conf->set_conf( md5 => $tmp );
+
+        return unless $file;
+    }
 
     ### read the file into a scalar, to store in the original object ###
     my $fh = new FileHandle;
@@ -1312,6 +1362,42 @@ sub _extutils_installed {
     }
 }
 
+=head2 $bool = $self->add_to_includepath;
+
+Adds the current modules path to C<@INC> and C<$PERL5LIB>. This allows
+you to add the module from it's build dir to your path.
+
+You can reset C<@INC> and C<$PERL5LIB> to it's original state when you
+started the program, by calling:
+
+    $self->parent->flush('lib');
+    
+=cut
+
+sub add_to_includepath {
+    my $self = shift;
+    my $cb   = $self->parent;
+    
+    if( my $dir = $self->status->extract ) {
+        
+            $cb->_add_to_includepath(
+                    directories => [
+                        File::Spec->catdir(BLIB->($dir), LIB),
+                        File::Spec->catdir(BLIB->($dir), ARCH),
+                        BLIB->($dir),
+                    ]
+            ) or return;
+        
+    } else {
+        error(loc(  "No extract dir registered for '%1' -- can not add ".
+                    "add builddir to search path!", $self->module ));
+        return;
+    }
+
+    return 1;
+
+}
+
 =pod
 
 =head2 $path = $self->best_path_to_module_build();
